/* type macros, generated by maketypes.awk */

#ifdef G_OS_WIN32
#  ifdef EEL_COMPILATION
#    define EELTYPEBUILTINS_VAR __declspec(dllexport)
#  else
#    define EELTYPEBUILTINS_VAR extern __declspec(dllimport)
#  endif
#else
#  ifdef EEL_COMPILATION
#    define EELTYPEBUILTINS_VAR
#  else
#    define EELTYPEBUILTINS_VAR extern
#  endif
#endif

EELTYPEBUILTINS_VAR GType EEL_TYPE_BACKGROUND_IMAGE_PLACEMENT;
EELTYPEBUILTINS_VAR GType EEL_TYPE_GDK_GEOMETRY_FLAGS;
EELTYPEBUILTINS_VAR GType EEL_TYPE_ELLIPSIZE_MODE;
EELTYPEBUILTINS_VAR GType EEL_TYPE_VFS_CAPABILITY;
EELTYPEBUILTINS_VAR GType EEL_TYPE_JUSTIFICATION;

#define	EEL_TYPE_N_BUILTINS	(5)
