#ifndef EEL_FEATURES_H
#define EEL_FEATURES_H 1

#define EEL_MAJOR_VERSION (2)
#define EEL_MINOR_VERSION (6)
#define EEL_MICRO_VERSION (2)
#define EEL_VERSION "2.6.2"

extern const unsigned int eel_major_version, eel_minor_version, eel_micro_version;
extern const char *eel_version;
#endif
